# DACTYL-Generation

A Python package to generate LLM data from various APIs. 

## Installation
```bash
pip install dactyl_generation
```

## Usage

Load environment variables (your API keys first) before importing the library. 
```python
# load environment variables first
from dotenv import load_dotenv
load_dotenv()

# now import library
from dactyl_generation.quick import *

```
